package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.tcZz.domain.TcWljgtj;
import com.ruoyi.tcZz.domain.TcWlmqfzr;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcWlwmzyz;
import com.ruoyi.tcZz.service.ITcWlwmzyzService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 网络文明志愿者Controller
 *
 * @author ruoyi
 * @date 2023-10-13
 */
@Api(tags = "网络文明志愿者")
@RestController
@RequestMapping("/tcZz/networkEcology/wlwmzyz")
public class TcWlwmzyzController extends BaseController {
    @Autowired
    private ITcWlwmzyzService tcWlwmzyzService;

    /**
     * 查询网络文明志愿者列表
     */
    @ApiOperation(value = "查询网络文明志愿者列表", response = TcWlwmzyz.class)
    @GetMapping("/list")
    public TableDataInfo list(TcWlwmzyz tcWlwmzyz) {
        startPage();
        List<TcWlwmzyz> list = tcWlwmzyzService.selectTcWlwmzyzList(tcWlwmzyz);
        return getDataTable(list);
    }

    /**
     * 导出网络文明志愿者列表
     */
    @ApiOperation(value = "导出网络文明志愿者列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcWlwmzyz tcWlwmzyz) {
        List<TcWlwmzyz> list = tcWlwmzyzService.selectTcWlwmzyzList(tcWlwmzyz);
        ExcelUtil<TcWlwmzyz> util = new ExcelUtil<TcWlwmzyz>(TcWlwmzyz.class);
        util.exportExcel(response, list, "网络文明志愿者数据");
    }

    /**
     * 获取网络文明志愿者详细信息
     */
    @ApiOperation(value = "获取网络文明志愿者详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcWlwmzyzService.selectTcWlwmzyzById(id));
    }

    /**
     * 新增网络文明志愿者
     */
    @ApiOperation(value = "新增网络文明志愿者")
    @PostMapping
    public AjaxResult add(@RequestBody TcWlwmzyz tcWlwmzyz) {
        return toAjax(tcWlwmzyzService.insertTcWlwmzyz(tcWlwmzyz));
    }

    /**
     * 修改网络文明志愿者
     */
    @ApiOperation(value = "修改网络文明志愿者")
    @PutMapping
    public AjaxResult edit(@RequestBody TcWlwmzyz tcWlwmzyz) {
        return toAjax(tcWlwmzyzService.updateTcWlwmzyz(tcWlwmzyz));
    }

    /**
     * 删除网络文明志愿者
     */
    @ApiOperation(value = "删除网络文明志愿者")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcWlwmzyzService.deleteTcWlwmzyzByIds(ids));
    }


    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcWlwmzyz> util = new ExcelUtil<TcWlwmzyz>(TcWlwmzyz.class);
        List<TcWlwmzyz> tcWlwmzyzList = util.importExcel(file.getInputStream());
        tcWlwmzyzService.importUser(tcWlwmzyzList);
        return AjaxResult.success();
    }
    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcWlwmzyzService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcWlwmzyz> util = new ExcelUtil<TcWlwmzyz>(TcWlwmzyz.class);
        util.importTemplateExcel(response, " 网络文明志愿者");
    }
}
